@@ -7,11 +7,11 @@ fai2 = rep(0.1,4)
 w2 = c(0.4,0.3,0.2,0.1)
 
 test_that("fai to w is correct",{
-    expect_equal(faiTow(fai1),w1)
-    expect_equal(faiTow(fai2),w2)
+    expect_equal(paramTow(fai1),w1)
+    expect_equal(paramTow(fai2),w2)
 })
 
 test_that("w to fai is correct",{
-    expect_equal(wTofai(w1),fai1)
-    expect_equal(wTofai(w2),fai2)
+    expect_equal(wToparam(w1),fai1)
+    expect_equal(wToparam(w2),fai2)
 })
\ No newline at end of file
